# Solid mechanics constraints

## Boundary conditions

::: phydrax.constraints.ContinuousTractionBoundaryConstraint

---

::: phydrax.constraints.ContinuousNormalDisplacementBoundaryConstraint

---

::: phydrax.constraints.ContinuousElasticFoundationBoundaryConstraint

---

::: phydrax.constraints.ContinuousElasticSymmetryBoundaryConstraint

---

::: phydrax.constraints.DiscreteDisplacementBoundaryConstraint

---

::: phydrax.constraints.DiscreteTractionBoundaryConstraint

---

::: phydrax.constraints.DiscreteNormalDisplacementBoundaryConstraint

## Integral / global constraints

::: phydrax.constraints.SolidTotalReactionBoundaryConstraint
